#! /usr/bin/env bash
#
# release.sh
#
# @LICENSE  Apache-2.0
# @AUTHOR   Hasnae Rehioui <hrehioui@atlassian.com>
#

withStatus() {
  echo $1
  eval $1
  status=$?
  if [ $status -ne 0 ]; then
    exit $status
  fi
}

npm set //registry.npmjs.org/:_authToken $NPM_TOKEN

COMMIT_MESSAGE=$(git log -1 --pretty=%B)

# setup git (required for version bump)
AUTHOR_NAME=$(git log -1 --pretty=%an)
AUTHOR_EMAIL=$(git log -1 --pretty=%ae)
REMOTE_URL=$(git config --get remote.origin.url)

git config --global user.name "$AUTHOR_NAME"
git config --global user.email "$AUTHOR_EMAIL"
git config --global push.default simple

# update remote url with write scope credentials
if [[ $REMOTE_URL =~ ^https://(.*)@bitbucket.org/((.*)/(.*))$ ]]; then
  echo set git remote
  git remote set-url origin https://${BASH_REMATCH[3]}:$BBCI_APP_PASSWORD@bitbucket.org/${BASH_REMATCH[2]}
fi

# bump version and apply tags if
# - main branch (master)
# and
# - commit match for [release:(major|minor|patch)]
BRANCH=$(git name-rev --name-only HEAD)


if [[ $BRANCH == 'master' ]] && [[ $COMMIT_MESSAGE =~ ^(.*)\[release:(minor|major|patch)\](.*)$ ]];
then
  bumpv=${BASH_REMATCH[2]}
  withStatus "npm version $bumpv -m '[bbci] releasing [version:%s]'"
  git push origin master --tags
  exit 0
fi

# publish if
# - main branch
# and
# - tags
# and
# - not previously published

TAGS=$(git tag --points-at HEAD)


if [ $TAGS ] && [[ $BRANCH == 'master' ]] && [[ $COMMIT_MESSAGE =~ ^(.*)\[version:(.*)\](.*)$ ]]; then
  withStatus "npm publish"
fi
